===========================================
Sharing neuroscience data in an open format
===========================================

.. FAIR, advantages of open formats

.. data from other formats, or from simulations


NIX
===



Neurodata Without Borders (NWB)
===============================
